# SPDX-FileCopyrightText: 2022-present Annie Ehler <annie.ehler.4@gmail.com>
#
# SPDX-License-Identifier: MIT
__version__ = "1.2.8"
__author__ = "Analetta (Annie) Ehler"
__author_email__ = "annie.ehler.4@gmail.com"
__license__ = "MIT"
__url__ = "https://github.com/annie444/SLEAPyFaces"
__description__ = """SLEAPyFaces is a Python package for
                   the analysis of SLEAP (Single-LEAP)
                   data of rodent faces."""
__all__ = [
    "__version__",
    "__author__",
    "__author_email__",
    "__license__",
    "__url__",
    "__description__",
]
